@@ -17,13 +17,13 @@ def generate_refline(bound_l: np.ndarray,
     Documentation:  This function takes track bounds and generates a reference line, including corresponding
                     normal-vectors and track-widths.
 
-    Inputs:         bound_{l/r}     bound coords (left / right) given as numpy array (columns holding x and y coords)
-                    resolution      desired resolution in meters
-
-    Outputs:        output_rl       coordinates of reference-line (columns holding x and y coords)
-                    v_normal        normal-vectors based on each of the reference-line coordinates
-                    tw_left         track-width to the left of reference point (along normal-vector)
-                    tw_right        track-width to the right of reference point (along normal-vector)
+    :param bound_l:         bound coords left given as numpy array (columns holding x and y coords)
+    :param bound_r:         bound coords right given as numpy array (columns holding x and y coords)
+    :param resolution:      desired resolution in meters
+    :returns (output_rl,    coordinates of reference-line (columns holding x and y coords)
+              v_normal,     normal-vectors based on each of the reference-line coordinates
+              tw_left,      track-width to the left of reference point (along normal-vector)
+              tw_right)     track-width to the right of reference point (along normal-vector)
     """
 
     if bound_l.shape[0] != bound_r.shape[0]:
