@@ -17,22 +17,20 @@ def get_scene_timesample(file_path: str,
                     neighboring time instances.
 
     Inputs:
-    - file_path:    string holding the path to the scene data file
-    - t_in:         two options:
-                     * float number holding the time stamp to be extracted [linear interp. between neighboring pts]
-                     * int number holding the number of the data reading to be extracted from the file
-
-    Outputs:
-    - time:         time stamp of the returned sample
-    - pos:          position of the ego vehicle (list holding x and y)
-    - heading:      heading of the ego vehicle (in the global frame)
-    - curv:         curvature of the path at the position of the ego vehicle
-    - vel:          velocity of the ego vehicle (in the direction of the heading)
-    - acc:          acceleration of the ego vehicle (in the direction of the heading)
-    - ego_traj:     planned ego trajectory starting at the current position (x, y, heading, curvature, vel, acc)
-    - ego_traj_em:  (if available, else ego_traj) planned emergency ego trajectory (x, y, heading, curvature, vel, acc)
-    - object_array: information about the vehicles in the scene (list of lists, each object holding an ID-string and a
-                    list holding [x, y, psi, obj_radius, vel])
+    :param file_path:       string holding the path to the scene data file
+    :param t_in:            two options:
+                            * float number holding the time-stamp to be extracted [linear interp. between neighb. pts]
+                            * int number holding the number of the data reading to be extracted from the file
+    :returns (time,         time stamp of the returned sample
+              pos,          position of the ego vehicle (list holding x and y)
+              heading,      heading of the ego vehicle (in the global frame)
+              curv,         curvature of the path at the position of the ego vehicle
+              vel,          velocity of the ego vehicle (in the direction of the heading)
+              acc,          acceleration of the ego vehicle (in the direction of the heading)
+              ego_traj,     planned ego trajectory starting at the current position (x, y, heading, curv., vel, acc)
+              ego_traj_em,  (if available, else ego_traj) planned emergency ego traj (x, y, heading, curv., vel, acc)
+              object_array) information about the vehicles in the scene (list of lists, each object holding an ID-string
+                            and a list holding [x, y, psi, obj_radius, vel])
     """
     # -- get timestamps ------------------------------------------------------------------------------------------------
     time_f = np.genfromtxt(file_path, delimiter=';', skip_header=2, names=True)['time']
@@ -151,11 +149,11 @@ def interp_1d(x: float,
     """
     extends the functionality of numpy's 'interp' to an array like structure
 
-    Input:
-    -x:                 Desired index for new value
-    -xp:                Existing series of indexes
-    -fp_array:          Array of existing function return values (matching xp)
-    - idx_col_heading:  List of ints holding the columns to be treated as headings (avoid jumps when crossing pi/-pi)
+    :param x:                desired index for new value
+    :param xp:               existing series of indexes
+    :param fp_array:         array of existing function return values (matching xp)
+    :param idx_col_heading:  list of ints holding columns to be treated as headings (avoid jumps when crossing pi/-pi)
+    :returns y_array:        array of interpolated values
     """
     y_array = np.zeros(fp_array.shape[1])
     for col in range(fp_array.shape[1]):
