@@ -11,10 +11,10 @@ def interp_heading(heading: np.ndarray,
     Documentation: Interpolate within a given heading course. (Converts to cos and sin, interpolates and converts back)
                    WARNING: Relies on small-angle approximation, i.e. the heading series should be tightly spaced.
 
-    Inputs:
-    heading:    heading course of original data
-    t_series:   series of time values (matching the heading course)
-    t_in:       time value for the heading to be generated
+    :param heading:             heading course of original data
+    :param t_series:            series of time values (matching the heading course)
+    :param t_in:                time value for the heading to be generated
+    :returns heading_interp:    resulting interpolated heading
     """
 
     # convert to x, y
